.. DataRobot Python Package documentation master file, created by
   sphinx-quickstart on Mon Mar 16 10:50:19 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

DataRobot Python package documentation
======================================

The DataRobot Python package is a client library for working with the DataRobot platform API. To access other clients and additional information about DataRobot's APIs, visit the `API documentation home <https://docs.datarobot.com/en/docs/api/index.html>`_.

Getting started
---------------

To get started with the Python client, reference `DataRobot's API Quickstart guide <https://docs.datarobot.com/en/docs/api/index.html>`_.



Table of contents
-----------------


.. toctree::
   :maxdepth: 2

   getting_started.rst
   reference/index.rst
   autodoc/api_reference.rst
   examples/index.rst
   CHANGES.rst


:ref:`genindex`
